#
# spec file for package python-openstacksdk
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname openstacksdk
Name:           python-openstacksdk
Version:        0.9.13
Release:        3.3
Summary:        An SDK for building applications to work with OpenStack
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://launchpad.net/python-openstacksdk
Source0:        https://pypi.io/packages/source/o/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-devel
BuildRequires:  python-fixtures >= 3.0.0
BuildRequires:  python-mock >= 2.0
BuildRequires:  python-pbr >= 1.8
BuildRequires:  python-requests >= 2.10.0
BuildRequires:  python-requests-mock >= 1.1
BuildRequires:  python-setuptools >= 16.0
BuildRequires:  python-six >= 1.9.0
BuildRequires:  python-stevedore >= 1.17.1
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testscenarios >= 0.4
BuildRequires:  python-testtools >= 1.4.0
Requires:       python-keystoneauth1 >= 2.17.0
Requires:       python-os-client-config >= 1.22.0
Requires:       python-six >= 1.9.0
Requires:       python-stevedore >= 1.17.1
BuildArch:      noarch

%description
The python-openstacksdk is a collection of libraries for building
applications to work with OpenStack clouds. The project aims to
provide a consistent and complete set of interactions with OpenStack's
many services, along with complete documentation, examples, and tools.

%package doc
Summary:        %{summary} - Documentation
Group:          Documentation/HTML
BuildRequires:  python-Sphinx
BuildRequires:  python-keystoneauth1 >= 2.17.0
BuildRequires:  python-openstackdocstheme >= 1.5.0
BuildRequires:  python-os-client-config >= 1.22.0
Requires:       %{name} = %{version}

%description doc
The python-openstacksdk is a collection of libraries for building
applications to work with OpenStack clouds. The project aims to
provide a consistent and complete set of interactions with OpenStack's
many services, along with complete documentation, examples, and tools.

This package contains documentation files for %{name}.

%prep
%autosetup -n %{sname}-%{version}
%py_req_cleanup

%build
%py2_build
%{__python2} setup.py build_sphinx
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%py2_install

%check
%{__python2} setup.py testr

%files
%license LICENSE
%doc ChangeLog README.rst
%{python2_sitelib}/openstack
%{python2_sitelib}/*.egg-info

%files doc
%license LICENSE
%doc doc/build/html

%changelog
* Fri Feb 10 2017 cloud-devel@suse.de
- update to version 0.9.13:
  - Add QoS bandwidth limit rule object and CRUD commands.
  - Add reset_state api for compute
  - Add new function for router-gateway
  - Add user_id in profile resource.
  - Add more server operations based on Nova API
  - Add filter "user_id" for cluster receiver list
  - Modified DHCP/Network Resource
  - Add QoS support to Network Port object.
  - Add filters to the network proxy agents() method
  - Fix error messages are not displayed correctly
  - Generalize endpoint determination
  - Fix Setting Quotas in Neutron
  - Rebase telemetry resources to resource2/proxy2
  - Add list method and query support for cinder volume and snapshot
  - Rebase network resources onto resource2 (1)
  - Support for node replace in cluster service
  - Provide better fallback when finding id values
  - Add QoS DSCP marking rule object and CRUD commands.
  - avoid usage of keystoneauth1 sessions
  - Chassis resource for bare-metal service
  - Rebase network proxy to proxy2
  - Update homepage with developer documentation page
  - Fix cluster query mapping
  - compute/v2/server: add ?all_tenants=bool to list
  - Add QoS minimum bandwidth rule object and CRUD commands.
  - Add filters provider-* to the network proxy networks() method
  - Revert "Event list can not display "timestamp"
  - Add filter options to the network proxy address_scopes() method()
  - Updated from global requirements
  - Prepare for baremetal API implementation
  - Fix connection init when session is provided
  - Document the `synchronized` parameter.
  - Obtain Image checksum via additional GET
  - Base for workflow service (mistral)
  - Driver resource for bare-metal service
  - Corrections in DHCP Agent Resource listing.
  - Rebase keystone v3 proxy to proxy2
  - Add support_status to policy type and profile type
  - Fix 'config_drive' and 'networks' for compute server
  - Add user_id in resource class Action/Node
  - Add support for network Service Flavor Profile
  - Modified Metering Rule base_path
  - Rebase network resources to resource2 (4)
  - Add docs for the workflow service
  - Add "sort" in policy binding list
  - Add limit and marker to QueryParameters class
  - Fix telemetry/metering service version
  - Initial docs for bare-metal service
  - Port resource for bare-metal service
  - Add project_id field to cluster's policy and profile
  - Add resource for DHCP Agent.
  - Rebase keystone resources onto resource2
  - Add 'project_id' field to volume resource
  - Proxy module for bare-metal service
  - Event list can not display "timestamp"
  - Support to delete claimed message
  - Remove beta label for network segment resource
  - Add standard attributes to the core network resources
  - Fix the issue non-admin user failed to list trusts
  - Add filters "policy_type" and "policy_name" for policy binding list
  - Document network resource query filters used by OSC
  - Adjust router add/remove interface method names
  - Remove dead code
  - Add workflow service (mistral)
  - Add QoS rule type object and CRUD commands.
  - Add Python 3.5 classifier and venv
  - Enable bare-metal service
  - Add user_id in resource class Policy
  - Fix the issue that 'type' field is missing in profile list
  - Display neutron api error message more precisely
  - Add filter "enabled" for cluster-policy-list
  - Add missing query parameters to compute v2 Server
  - Add support for Role resource in Identity v3
  - Fix metadata property of Senlin node resource
  - Add QoS support to Network object.
  - Clarify argparse connections
  - Node resource for bare-metal service
  - Add network segment create, delete and update support
  - Add filters to the router proxy routers() method
  - Rebase network resources to resource2 (3)
  - Add project ID in QuotaDefault requests
  - Added is_shared resource to Metering Label
  - Fix problem about location header in Zaqar resource2
  - Add 'project_id' field to cluster's action resource
  - Add auto-allocated-topology to SDK
  - Network L3 Router Commands
  - Add support for network Flavor
  - Add resources for Service Provider
  - Add support for filter "status" in node list
  - Add extended Glance Image properties
  - Add service_type resource to Subnets
  - Add filter mac_address to the network proxy ports() method
  - Revert "Display neutron api error message more precisely"
  - Rebase network resources onto resource2 (2)
  - Modified Metering base_path
  - PortGroup resource for bare-metal service
  - Fix error in node action
  - Add dns-domain support to Network object.
  - Add 'dependents' property to Node and Cluster class
* Sun Oct  2 2016 dmueller@suse.com
- revert last change (go back to 0.9.5, which is Newton)
* Fri Sep 23 2016 mjura@suse.com
  update to version 0.9.7
  * Revert "Event list can not display "timestamp"
  * Event list can not display "timestamp"
  * Add project_id field to cluster's policy and profile
  * Fix the issue non-admin user failed to list trusts
  * Fix error in node action
  * compute/v2/server: add ?all_tenants=bool to list
  update to version 0.9.6
  * Add extended Glance Image properties
  * Fix connection init when session is provided
  * Rebase keystone v3 proxy to proxy2
  * Fix 'config_drive' and 'networks' for compute server
  * Fix cluster query mapping
  * Rebase keystone resources onto resource2
  * Add new function for router-gateway
  * Obtain Image checksum via additional GET
  * Adjust router add/remove interface method names
  * Add 'dependents' property to Node and Cluster class
  * Add QoS rule type object and CRUD commands
  * Add QoS bandwidth limit rule object and CRUD commands
  * Add QoS DSCP marking rule object and CRUD commands
  * Add QoS minimum bandwidth rule object and CRUD commands
  * Add network segment create, delete and update support
  * Rebase telemetry resources to resource2/proxy2
  * Fix telemetry/metering service version
  * Fix the issue that 'type' field is missing in profile list
* Fri Sep  2 2016 tbechtold@suse.com
  update to version 0.9.5
  * Updated from global requirements
  * Fix issue "SDKException: Connection failure that may be retried."
* Tue Aug 30 2016 tbechtold@suse.com
  update to version 0.9.4
  * Add SoftwareDeployment resource to orchestration
  * Add policy validation for senlin
  * Fix cluster resource in cluster service
  * Add API microversion support
  * Add collect_cluster_attrs API to cluster service
  * Remove update_flavor method from compute
  * Fix problems about location header in resource2
  * Add SoftwareConfig resource to orchestration
  * _alternate_id should return a server-side name
  * Add support for message resource of Zaqar v2 API
  * Relocate alarm service into a submodule
  * Add support for claim for Zaqar V2 API
  * Add QoS policy object and CRUD commands.
  * Replace _transpose_component with _filter_component
  * Tweak endpoint discovery for apache-style services
  * Improve docstring for some resource2 methods
  * Add services operations into compute service
  * Add 'check_stack' operation to proxy
  * Fix test_limits functional test failure
  * Add profile validation for senlin
  * Add force-delete into compute service
  * Make end-user modules accessible from top level
  * Fix orchestration service initialization
  * HAProxy uses milliseconds for its timeout values.
  * Rebase cluster service to resource2/proxy2
  * Rebase orchestration to resource2/proxy2
  * Support fetching network project default quota
  * Add support for Zaqar V2 queue resource
  * Fix nova server image and flavor
  * Add 'to_dict()' method to resource2.Resource
  * Minor network RBAC policy updates
  * Add template validation support to orchestration
  * Refactor Key Manager for resource2
  * Get endpoints directly from services
  * Refactor image v2 to use resource2/proxy2
  * Updated from global requirements
  * Add support for subscription for Zaqar V2 API
  * Expose 'requires_id' to get_xxx proxy functions
* Fri Jul 22 2016 tbechtold@suse.com
- update to version 0.9.0:
  * Refactor compute for new resource/proxy
  * Allow alternate_id to be accessed directly
  * Add neutron rbac support
  * Updated from global requirements
  * Add temporary test_proxy_base2
  * Add segment_id property to subnet resource
  * Allow resources to check their equality
  * Remove type=timestamp usages
  * Cluster user guide - part 2
  * Move version definition
  * Fix clustering event properties
- update _service and switch to upstream .spec file
* Tue May  3 2016 dmueller@suse.com
- update to 0.8.5:
  * Trivial: Fix typo in update_port() comment
  * Support client certificate/key
  * Add network resource properties
  * Updated from global requirements
  * Properly handle overridden Body properties
* Fri Apr  8 2016 tbechtold@suse.com
- update to 0.8.4:
  * Refactor Resource to better serve Proxy
  * Consistent resource.prop for timestamps and booleans (cluster
  * Add address scope CRUD
  * Consistent resource.prop for timestamps and booleans (object store)
  * Consistent resource.prop for timestamps and booleans (network)
  * Consistent resource.prop for timestamps and booleans (identity)
  * Cluster user guide - first step
  * Consistent resource.prop for timestamps and booleans (orchestration)
  * Consistent resource.prop for timestamps and booleans (telemetry)
  * Fix image member apis
  * Fix content-type for swift upload
  * Fix key manager secret resource object
  * Consistent resource.prop for timestamps and booleans (key manager)
  * Consistent resource.prop for timestamps and booleans (image)
  * Make metadata handling consistent in Compute
  * Fix coverage configuration and execution
  * Consistent resource.prop for timestamps and booleans (compute)
  * Fix functional tests
  * Add/Remove port interface to a router
  * Consistent resource.prop for timestamps and booleans (block store)
  * Consistent resource.prop for timestamps and booleans (metric)
* Mon Mar 14 2016 tbechtold@suse.com
- update to 0.8.1:
  * Add Hypervisor support to Compute Service
- Update description
- Add BuildRequires for testing but testing is still disabled.
* Wed Mar  2 2016 tbechtold@suse.com
- update to 0.8.0:
  * Add Nova server group resource
  * Make metadata handling consistent in Object Store
  * Updated from global requirements
  * Override delete function of senlin cluster/node
  * Basic resource.prop for ID attributes (message)
  * Basic resource.prop for ID attributes (cluster)
  * Adding Check/Recover Actions to Clusters
  * Basic resource.prop for ID attributes (block store)
  * Basic resource.prop for ID attributes (orchestration)
  * Fix compute tests for resource.prop ID attributes
  * Basic resource.prop for ID attributes (compute)
  * Basic resource.prop for ID attributes (image)
  * Basic resource.prop for ID attributes (identity)
  * Basic resource.prop for ID attributes (telemetry)
  * Update attributes uses hard coded id
  * Adding check/recover actions to cluster nodes
  * Basic resource.prop for ID attributes (network)
  * Remove 'date' from Object resource
  * Make functional test resources configurable
  * Fix Port resource properties
  * Refactor profile set_ methods
  * Add UNIXEpoch formatter as a type for properties
  * Update create_network function in test_network
  * Documentation for cluster API and resources
  * Resource object attributes not updated on some interfaces
  * Add ISO8601 formatter as a type for properties
  * Add LoadBalancer vip_port_id and provider properties
  * Raise NotFound exception when get a deleted stack
  * Updated from global requirements
  * download_object/get_object must have the same API
  * Map KSA exception to SDK exceptions
  * Fix URLs for CLI Reference
  * Updated from global requirements
  * Send keystoneauth a better user-agent string
  * Add network availability zone support
  * Allow resource get to carry query string
  * Rework cluster API
  * Skip test class unless a service exists
  * Add attribute 'location' to base resource
  * Add preview_stack for orchestration
  * Update Quota documentation and properties
  * Update Subnet Pools Documentation
  * Update router's functional tests to validate is_ha property
  * Updated from global requirements
  * Use assertTrue/False instead of assertEqual(T/F)
  * Remove status property from LBaaS resources
  * Add functional tests for DVR router
  * Add missing Listener resource properties
  * Better support for metadata in Compute service
  * Add image user guide
  * s/save/download/
  * Replace assertTrue(isinstance()) with assertIsInstance()
  * Replace assertEqual(None, *) with assertIsNone in tests
  * Add support for availability zone request
  * Add proxy methods for node actions (cluster)
  * Rename timestamp fields for cluster service
  * Add cluster actions to cluster proxy
  * Fix docstring of resource_id parameter in resource module
  * Fix server action resource call
  * Correct response value in resource unittests
  * Raise not found error if stack is deleted when find_stack
  * Add Receiver resource to cluster service
  * Add Subnet Pool CRUD
  * remove python 2.6 trove classifier
  * Add Quota RUD and missing properties
  * Add 'resize' action to cluster
  * Return None when getting an attr which is None when using resource.prop()
  * Add Network mtu and port_security_enabled properties
  * Support block_store types where IDs are taken
  * Remove requests from requirements
  * cluster: Use typed props instead of *_id
  * Updated from global requirements
  * Rename key_management to key_manager
  * Replace 'value' arguments in telemetry proxy
  * Add Port port_security_enabled property
  * Replace 'value' arguments in orchestration proxy
  * Replace 'value' arguments in object_store proxy
  * Replace 'value' arguments in network proxy
  * Replace 'value' arguments in key_management proxies
  * Replace 'value' arguments in image proxies
  * Fix exceptions to catch for ignore_missing
  * Updated from global requirements
  * Add admonition to telemetry code
  * Add Router ha, distributed and routes properties
  * Fix "report a bug" launchpad project
  * Add PolicyType resource for clustering
  * Add 'ProfileType' resource for senlin
  * block_store and cluster: replace 'value' arguments
  * Add cluster-policy binding resource to Senlin
  * Skip orchestration functional tests
  * Replace 'value' arguments in identity proxies
  * Replace 'value' arguments in database proxy
  * Replace 'value' arguments in compute proxy
  * Update doc link in README
  * Remove oslosphinx
  * Skip broken functional tests
  * Delete key pair and server for Compute example
  * Fix 400 error in compute examples
  * Fix post test hook script
  * Remove the Metric proxy
  * Remove an extra dangling doc reference to CDN
  * Remove incomplete CDN code
  * Fix failing compute example
  * Updated from global requirements
  * Updated from global requirements
  * Add identity user guide
  * Doc: Add instructions for creating cloud.yaml
  * Replace stackforge with openstack
  * Add BuildInfo resource to cluster service
  * Updated from global requirements
  * Add network user guide
  * Add authorize method to Connection
  * Avoid Pool object creating in pool_member functional calls
  * Fix cluster action api invocations
  * Add rebuild_server function call
  * Replace 'MagicMock' with 'Mock'
  * Updated from global requirements
  * Trivial: Fix a typo in resource.py
  * Add server resize function calls
  * Make nova server_interface function calls work
  * Fix typo in action test case
  * Add event resource for senlin(cluster) service
  * Remove missing capability
  * Remove some dead exception types
  * Fix senlin update verb
  * Replace 'MagicMock' with 'Mock'
  * Publicize the _convert_id call of Resource class
  * Try running examples tests on gate
  * Add documentation for testing examples
  * Cleanup doc references to past modules
  * Use consistent argument names for find proxies
  * find_security_group_rule does not find by name
  * Updates doc enviro to use OpenStack Docs theme
- add _service file
- update Requires according to requirements.txt
* Tue Dec  8 2015 bwiedemann@suse.com
- initial version 0.7.1
